==> v0.9.0.tar.gz: itgmania-0.9.0/src/arch/Lights/LightsDriver_Linux_Leds.h <==
/* LightsDriver_Linux_Leds: Control Linux system lights via /sys/class/leds */

#ifndef LightsDriver_Linux_Leds_H
#define LightsDriver_Linux_Leds_H

#include "arch/Lights/LightsDriver.h"

#include <cstdint>

class LightsDriver_Linux_Leds : public LightsDriver
{
private:
	static const std::uint8_t LINUX_LED_STATE_ON = 255;
	static const std::uint8_t LINUX_LED_STATE_OFF = 0;
	static const int LINUX_LED_MAX_DIRECTORY_LENGTH = PATH_MAX;

	const InputScheme *pInput;
	RString sInputName;

	bool WriteLight(const char *filename, bool state);

protected:
	LightsState previousLS;

	bool IsDance();
	bool IsPump();

	void SetLight(const char *filename, bool previous, bool desired);

	void SetCabinetLights(const char *stringArray[], const LightsState *ls);
	void SetCabinetLights(const int intArray[], const LightsState *ls);

	void SetGameControllerLights(GameController gc, const char *stringArray[], const LightsState *ls);
	void SetGameControllerLights(GameController gc, const int intArray[], const LightsState *ls);

public:
	virtual void Set(const LightsState *ls) = 0;
	virtual const char *GetGameControllerLightFile() = 0;
};

#endif

/*
 * (c) 2020 din
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 * i love lamp
 */

==> v1.0.0.tar.gz: itgmania-1.0.0/src/arch/Lights/LightsDriver_Linux_Leds.h <==
/* LightsDriver_Linux_Leds: Control Linux system lights via /sys/class/leds */

#ifndef LightsDriver_Linux_Leds_H
#define LightsDriver_Linux_Leds_H

#include "arch/Lights/LightsDriver.h"

#include <cstdint>

class LightsDriver_Linux_Leds : public LightsDriver
{
private:
	static const uint8_t LINUX_LED_STATE_ON = 255;
	static const uint8_t LINUX_LED_STATE_OFF = 0;
	static const int LINUX_LED_MAX_DIRECTORY_LENGTH = PATH_MAX;

	const InputScheme *pInput;
	RString sInputName;

	bool WriteLight(const char *filename, bool state);

protected:
	LightsState previousLS;

	bool IsDance();
	bool IsPump();

	void SetLight(const char *filename, bool previous, bool desired);

	void SetCabinetLights(const char *stringArray[], const LightsState *ls);
	void SetCabinetLights(const int intArray[], const LightsState *ls);

	void SetGameControllerLights(GameController gc, const char *stringArray[], const LightsState *ls);
	void SetGameControllerLights(GameController gc, const int intArray[], const LightsState *ls);

public:
	virtual void Set(const LightsState *ls) = 0;
	virtual const char *GetGameControllerLightFile() = 0;
};

#endif

/*
 * (c) 2020 din
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
 * THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS
 * INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT
 * OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
 * OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 * i love lamp
 */
